#pragma once
#define GIT_COMMIT_HASH    "386376400119dd46a767c9f8c8791fd22c7b6e61"
#define GIT_BRANCH         "v0.52.2"
#define GIT_COMMIT_MESSAGE "[gha] Nix: update inputs"
#define GIT_COMMIT_DATE    "Wed Dec 3 22:59:30 2025"
#define GIT_DIRTY          "clean"
#define GIT_TAG            "v0.52.2"
#define GIT_COMMITS        "6581"

#define AQUAMARINE_VERSION "0.10.0"
// clang-format off
#define AQUAMARINE_VERSION_MAJOR 0
#define AQUAMARINE_VERSION_MINOR 10
#define AQUAMARINE_VERSION_PATCH 0
// clang-format on
#define HYPRLANG_VERSION     "0.6.7"
#define HYPRUTILS_VERSION    "0.10.4"
#define HYPRCURSOR_VERSION   "0.1.13"
#define HYPRGRAPHICS_VERSION "0.4.0"
